@@ -22,21 +22,17 @@ import json
 import subprocess
 import sys
 import tempfile
-
 from pathlib import Path
-from typing import Callable, Dict, List, Tuple, Union
-from packaging.version import InvalidVersion, Version
+from typing import Callable, Dict, Iterator, List, Tuple, Union
 
 import requests
+from packaging.version import InvalidVersion, Version
 
 from pontos import version
-from pontos.terminal import error, warning, info, ok, out, overwrite
-from pontos.terminal.terminal import Signs
+from pontos.helper import DownloadProgressIterable
+from pontos.terminal import Terminal
+from pontos.version import CMakeVersionCommand, PythonVersionCommand
 from pontos.version.helper import VersionError
-from pontos.version import (
-    PythonVersionCommand,
-    CMakeVersionCommand,
-)
 
 DEFAULT_TIMEOUT = 1000
 DEFAULT_CHUNK_SIZE = 4096
@@ -46,8 +42,8 @@ def build_release_dict(
     release_version: str,
     release_changelog: str,
     *,
-    name: str = '',
-    target_commitish: str = '',
+    name: str = "",
+    target_commitish: str = "",
     draft: bool = False,
     prerelease: bool = False,
 ) -> Dict[str, Union[str, bool]]:
@@ -69,16 +65,16 @@ def build_release_dict(
     """
     tag_name = (
         release_version
-        if release_version.startswith('v')
+        if release_version.startswith("v")
         else "v" + release_version
     )
     return {
-        'tag_name': tag_name,
-        'target_commitish': target_commitish,
-        'name': name,
-        'body': release_changelog,
-        'draft': draft,
-        'prerelease': prerelease,
+        "tag_name": tag_name,
+        "target_commitish": target_commitish,
+        "name": name,
+        "body": release_changelog,
+        "draft": draft,
+        "prerelease": prerelease,
     }
 
 
@@ -87,7 +83,7 @@ def commit_files(
     commit_msg: str,
     shell_cmd_runner: Callable,
     *,
-    git_signing_key: str = '',
+    git_signing_key: str = "",
     changelog: bool = False,
 ):
     """Add files to staged and commit staged files.
@@ -118,11 +114,11 @@ def commit_files(
         shell_cmd_runner(f"git commit --no-verify -m '{commit_msg}'")
 
 
-def calculate_calendar_version() -> str:
+def calculate_calendar_version(terminal: Terminal) -> str:
     """find the correct next calendar version by checking latest version and
     the today's date"""
 
-    current_version_str: str = get_current_version()
+    current_version_str: str = get_current_version(terminal)
     current_version = Version(current_version_str)
 
     today = datetime.date.today()
@@ -132,7 +128,7 @@ def calculate_calendar_version() -> str:
         or current_version.minor < today.month
     ):
         release_version = Version(
-            f'{str(today.year  % 100)}.{str(today.month)}.0'
+            f"{str(today.year  % 100)}.{str(today.month)}.0"
         )
         return str(release_version)
     elif (
@@ -141,17 +137,17 @@ def calculate_calendar_version() -> str:
     ):
         if current_version.dev is None:
             release_version = Version(
-                f'{str(today.year  % 100)}.{str(today.month)}.'
-                f'{str(current_version.micro + 1)}'
+                f"{str(today.year  % 100)}.{str(today.month)}."
+                f"{str(current_version.micro + 1)}"
             )
         else:
             release_version = Version(
-                f'{str(today.year  % 100)}.{str(today.month)}.'
-                f'{str(current_version.micro)}'
+                f"{str(today.year  % 100)}.{str(today.month)}."
+                f"{str(current_version.micro)}"
             )
         return str(release_version)
     else:
-        error(
+        terminal.error(
             f"'{str(current_version)}' is higher than "
             f"'{str(today.year  % 100)}.{str(today.month)}'."
         )
@@ -159,128 +155,110 @@ def calculate_calendar_version() -> str:
 
 
 def download(
+    terminal: Terminal,
     url: str,
     filename: str,
-    requests_module: requests,
-    path: Path,
+    requests_module: requests = requests,
+    path: Path = Path,
     *,
     chunk_size: int = DEFAULT_CHUNK_SIZE,
     timeout: int = DEFAULT_TIMEOUT,
-) -> Path:
+) -> DownloadProgressIterable:
     """Download file in url to filename
 
     Arguments:
+        terminal: Terminal to print download info to
         url: The url of the file we want to download
         filename: The name of the file to store the download in
         requests_module: the python request module
         path: the python pathlib.Path module
 
     Returns:
-       Path to the downloaded file
+       A DownloadProgressIterable for iterating over the download progress
     """
 
-    file_path: Path = path(tempfile.gettempdir()) / filename
+    destination: Path = path(tempfile.gettempdir()) / filename
     response = requests_module.get(url, stream=True, timeout=timeout)
-    total_length = response.headers.get('content-length')
+    total_length = response.headers.get("content-length")
 
-    info(f'Downloading {url}')
+    terminal.info(f"Downloading {url}")
 
-    if total_length is not None:  # no content length header
-        with file_path.open(mode='wb') as download_file:
-            dl = 0
-            total_length = int(total_length)
-            for content in response.iter_content(chunk_size=chunk_size):
-                dl += len(content)
-                download_file.write(content)
-                done = int(50 * dl / total_length)
-                overwrite(f"[{'=' * done}{' ' * (50-done)}]")
-    else:
-        with file_path.open(mode='wb') as download_file:
-            spinner = ['-', '\\', '|', '/']
-            i = 0
-            for content in response.iter_content(chunk_size=chunk_size):
-                i = i + 1
-                if i == 4:
-                    i = 0
-                download_file.write(content)
-                overwrite(f"[{spinner[i]}]")
-    overwrite(f"[{Signs.OK}]{' ' * 50}", new_line=True)
-
-    return file_path
+    return DownloadProgressIterable(
+        response.iter_content(chunk_size=chunk_size),
+        destination,
+        total_length,
+    )
 
 
 def download_assets(
+    terminal: Terminal,
     assets_url: str,
-    path: Path,
-    requests_module: requests,
-) -> List[str]:
+    path: Path = Path,
+    requests_module: requests = requests,
+) -> Iterator[DownloadProgressIterable]:
     """Download all .tar.gz and zip assets of a github release"""
 
-    file_paths = []
     if not assets_url:
-        return file_paths
+        return
 
-    if assets_url:
-        assets_response = requests_module.get(assets_url)
-        if assets_response.status_code != 200:
-            error(
-                f"Wrong response status code {assets_response.status_code} for "
-                f" request {assets_url}"
-            )
-            out(json.dumps(assets_response.text, indent=4, sort_keys=True))
-        else:
-            assets_json = assets_response.json()
-            for asset_json in assets_json:
-                asset_url: str = asset_json.get('browser_download_url', '')
-                name: str = asset_json.get('name', '')
-                if name.endswith('.zip') or name.endswith('.tar.gz'):
-                    asset_path = download(
-                        asset_url,
-                        name,
-                        path=path,
-                        requests_module=requests_module,
-                    )
-                    file_paths.append(asset_path)
-
-    return file_paths
+    assets_response = requests_module.get(assets_url)
+    if assets_response.status_code != 200:
+        terminal.error(
+            f"Wrong response status code {assets_response.status_code} for "
+            f" request {assets_url}"
+        )
+        terminal.out(json.dumps(assets_response.text, indent=4, sort_keys=True))
+    else:
+        assets_json = assets_response.json()
+        for asset_json in assets_json:
+            asset_url: str = asset_json.get("browser_download_url", "")
+            name: str = asset_json.get("name", "")
+            if name.endswith(".zip") or name.endswith(".tar.gz"):
+                yield download(
+                    terminal,
+                    asset_url,
+                    name,
+                    path=path,
+                    requests_module=requests_module,
+                )
 
 
-def get_current_version() -> str:
+def get_current_version(terminal: Terminal) -> str:
     """Get the current Version from a pyproject.toml or
     a CMakeLists.txt file"""
 
     available_cmds = [
-        ('CMakeLists.txt', CMakeVersionCommand),
-        ('pyproject.toml', PythonVersionCommand),
+        ("CMakeLists.txt", CMakeVersionCommand),
+        ("pyproject.toml", PythonVersionCommand),
     ]
     for file_name, cmd in available_cmds:
         project_definition_path = Path.cwd() / file_name
         if project_definition_path.exists():
-            ok(f"Found {file_name} project definition file.")
+            terminal.ok(f"Found {file_name} project definition file.")
             current_version: str = cmd().get_current_version()
             return current_version
 
-    error("No project settings file found")
+    terminal.error("No project settings file found")
     sys.exit(1)
 
 
-def get_next_patch_version() -> str:
+def get_next_patch_version(terminal: Terminal) -> str:
     """find the correct next patch version by checking latest version"""
 
-    current_version_str: str = get_current_version()
+    current_version_str: str = get_current_version(terminal)
     current_version = Version(current_version_str)
 
     if current_version.dev is not None:
         release_version = Version(
-            f'{str(current_version.major)}.'
-            f'{str(current_version.minor)}.'
-            f'{str(current_version.micro)}'
+            f"{str(current_version.major)}."
+            f"{str(current_version.minor)}."
+            f"{str(current_version.micro)}"
         )
     else:
         release_version = Version(
-            f'{str(current_version.major)}.'
-            f'{str(current_version.minor)}.'
-            f'{str(current_version.micro + 1)}'
+            f"{str(current_version.major)}."
+            f"{str(current_version.minor)}."
+            f"{str(current_version.micro + 1)}"
         )
 
     return str(release_version)
@@ -292,9 +270,9 @@ def get_next_dev_version(release_version: str) -> str:
     try:
         release_version_obj = Version(release_version)
         next_version_obj = Version(
-            f'{str(release_version_obj.major)}.'
-            f'{str(release_version_obj.minor)}.'
-            f'{str(release_version_obj.micro + 1)}'
+            f"{str(release_version_obj.major)}."
+            f"{str(release_version_obj.minor)}."
+            f"{str(release_version_obj.micro + 1)}"
         )
         return str(next_version_obj)
     except InvalidVersion as e:
@@ -304,7 +282,7 @@ def get_next_dev_version(release_version: str) -> str:
 def get_project_name(
     shell_cmd_runner: Callable,
     *,
-    remote: str = 'origin',
+    remote: str = "origin",
 ) -> str:
     """Get the git repository name
 
@@ -315,11 +293,11 @@ def get_project_name(
     Returns:
         project name
     """
-    ret = shell_cmd_runner(f'git remote get-url {remote}')
-    return ret.stdout.split('/')[-1].replace('.git', '').strip()
+    ret = shell_cmd_runner(f"git remote get-url {remote}")
+    return ret.stdout.split("/")[-1].replace(".git", "").strip()
 
 
-def find_signing_key(shell_cmd_runner: Callable) -> str:
+def find_signing_key(terminal: Terminal, shell_cmd_runner: Callable) -> str:
     """Find the signing key in the config
 
     Arguments:
@@ -330,14 +308,14 @@ def find_signing_key(shell_cmd_runner: Callable) -> str:
     """
 
     try:
-        proc = shell_cmd_runner('git config user.signingkey')
+        proc = shell_cmd_runner("git config user.signingkey")
     except subprocess.CalledProcessError as e:
         # The command `git config user.signingkey` returns
         # return code 1 if no key is set.
         # So we will return empty string ...
         if e.returncode == 1:
-            warning("No signing key found.")
-        return ''
+            terminal.warning("No signing key found.")
+        return ""
     # stdout should return "\n" if no key is available
     # and so git_signing_key should
     # return '' if no key is available ...
@@ -345,7 +323,7 @@ def find_signing_key(shell_cmd_runner: Callable) -> str:
 
 
 def update_version(
-    to: str, _version: version, *, develop: bool = False
+    terminal: Terminal, to: str, _version: version, *, develop: bool = False
 ) -> Tuple[bool, str]:
     """Use pontos-version to update the version.
 
@@ -358,23 +336,24 @@ def update_version(
        executed: True if successfully executed, False else
        filename: The filename of the project definition
     """
-    args = ['--quiet']
-    args.append('update')
+    args = ["--quiet"]
+    args.append("update")
     args.append(to)
     if develop:
-        args.append('--develop')
+        args.append("--develop")
     executed, filename = _version.main(leave=False, args=args)
 
     if not executed:
         if filename == "":
-            error("No project definition found.")
+            terminal.error("No project definition found.")
         else:
-            error(f"Unable to update version {to} in {filename}")
+            terminal.error(f"Unable to update version {to} in {filename}")
 
     return executed, filename
 
 
 def upload_assets(
+    terminal: Terminal,
     username: str,
     token: str,
     file_paths: List[Path],
@@ -396,14 +375,14 @@ def upload_assets(
     Returns:
         True on success, false else
     """
-    info(f"Uploading assets: {[str(p) for p in file_paths]}")
+    terminal.info(f"Uploading assets: {[str(p) for p in file_paths]}")
 
-    asset_url = github_json['upload_url'].replace('{?name,label}', '')
-    paths = [path(f'{str(p)}.asc') for p in file_paths]
+    asset_url = github_json["upload_url"].replace("{?name,label}", "")
+    paths = [path(f"{str(p)}.asc") for p in file_paths]
 
     headers = {
-        'Accept': 'application/vnd.github.v3+json',
-        'content-type': 'application/octet-stream',
+        "Accept": "application/vnd.github.v3+json",
+        "content-type": "application/octet-stream",
     }
     auth = (username, token)
 
@@ -417,13 +396,13 @@ def upload_assets(
         )
 
         if resp.status_code != 201:
-            error(
+            terminal.error(
                 f"Wrong response status {resp.status_code}"
                 f" while uploading {file_path.name}"
             )
-            out(json.dumps(resp.text, indent=4, sort_keys=True))
+            terminal.out(json.dumps(resp.text, indent=4, sort_keys=True))
             return False
         else:
-            ok(f"Uploaded: {file_path.name}")
+            terminal.ok(f"Uploaded: {file_path.name}")
 
     return True
