@@ -16,16 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from argparse import Namespace
-from pathlib import Path
 import unittest
+from argparse import Namespace
 from dataclasses import dataclass
 from datetime import datetime
-
-from pontos.terminal import _set_terminal
-from pontos.terminal.terminal import Terminal
+from pathlib import Path
+from subprocess import CompletedProcess
+from unittest.mock import MagicMock, call, patch
 
 from pontos import changelog
+from pontos.changelog.conventional_commits import parse_args
 
 
 @dataclass
@@ -34,48 +34,47 @@ class StdOutput:
 
 
 class ConventionalCommitsTestCase(unittest.TestCase):
-    def test_changelog_builder(self):
+    @patch("pontos.changelog.conventional_commits.shell_cmd_runner")
+    def test_changelog_builder(self, shell_mock):
+        terminal = MagicMock()
 
-        _set_terminal(Terminal())
-
-        today = datetime.today().strftime('%Y-%m-%d')
+        today = datetime.today().strftime("%Y-%m-%d")
 
         own_path = Path(__file__).absolute().parent
-        print(own_path)
-        config_toml = own_path / 'changelog.toml'
-        release_version = '0.0.2'
-        output = f'v{release_version}.md'
-        git_tag = "v0.0.1"
-        git_log = (
-            '1234567 Add: foo bar\n'
-            '8abcdef Add: bar baz\n'
-            '8abcd3f Add bar baz\n'
-            '8abcd3d Adding bar baz\n'
-            '1337abc Change: bar to baz\n'
-            '42a42a4 Remove: foo bar again\n'
-            'fedcba8 Test: bar baz testing\n'
-            'dead901 Refactor: bar baz ref\n'
-            'fedcba8 Fix: bar baz fixing\n'
-            'd0c4d0c Doc: bar baz documenting\n'
-        )
-        called = []
+        config_toml = own_path / "changelog.toml"
+        release_version = "0.0.2"
+        output = f"v{release_version}.md"
 
-        def runner(cmd):
-            called.append(cmd)
-            if cmd == "git tag | sort -V | tail -1":
-                return StdOutput(git_tag)
-            return StdOutput(git_log)
+        shell_mock.side_effect = [
+            CompletedProcess(args=None, returncode=1, stdout="v0.0.1"),
+            CompletedProcess(
+                args=None,
+                returncode=1,
+                stdout=(
+                    "1234567 Add: foo bar\n"
+                    "8abcdef Add: bar baz\n"
+                    "8abcd3f Add bar baz\n"
+                    "8abcd3d Adding bar baz\n"
+                    "1337abc Change: bar to baz\n"
+                    "42a42a4 Remove: foo bar again\n"
+                    "fedcba8 Test: bar baz testing\n"
+                    "dead901 Refactor: bar baz ref\n"
+                    "fedcba8 Fix: bar baz fixing\n"
+                    "d0c4d0c Doc: bar baz documenting\n"
+                ),
+            ),
+        ]
 
         cargs = Namespace(
-            current_version='0.0.1',
+            current_version="0.0.1",
             next_version=release_version,
             output=output,
-            space='foo',
-            project='bar',
+            space="foo",
+            project="bar",
             config=config_toml,
         )
         changelog_builder = changelog.ChangelogBuilder(
-            shell_cmd_runner=runner,
+            terminal=terminal,
             args=cargs,
         )
         expected_output = f"""# Changelog
@@ -108,49 +107,42 @@ All notable changes to this project will be documented in this file.
 
 [0.0.2]: https://github.com/foo/bar/compare/0.0.1...0.0.2"""
         output_file = changelog_builder.create_changelog_file()
-        print(output_file.read_text(encoding='utf-8'))
         self.assertEqual(
-            output_file.read_text(encoding='utf-8'), expected_output
+            output_file.read_text(encoding="utf-8"), expected_output
         )
 
-        self.assertIn(
-            'git tag | sort -V | tail -1',
-            called,
-        )
-
-        self.assertIn(
-            'git log "v0.0.1..HEAD" --oneline',
-            called,
+        shell_mock.assert_has_calls(
+            [
+                call("git tag | sort -V | tail -1"),
+                call('git log "v0.0.1..HEAD" --oneline'),
+            ]
         )
 
         output_file.unlink()
 
-    def test_changelog_builder_no_commits(self):
-
-        _set_terminal(Terminal())
+    @patch("pontos.changelog.conventional_commits.shell_cmd_runner")
+    def test_changelog_builder_no_commits(self, shell_mock):
+        terminal = MagicMock()
 
         own_path = Path(__file__).absolute().parent
-        print(own_path)
-        config_toml = own_path / 'changelog.toml'
-        release_version = '0.0.2'
-        output = f'v{release_version}.md'
-        git_log = '1234567 foo bar\n8abcdef bar baz\n'
-        called = []
+        config_toml = own_path / "changelog.toml"
+        release_version = "0.0.2"
+        output = f"v{release_version}.md"
 
-        def runner(cmd):
-            called.append(cmd)
-            return StdOutput(git_log)
+        shell_mock.return_value = CompletedProcess(
+            args=None, returncode=1, stdout="1234567 foo bar\n8abcdef bar baz\n"
+        )
 
         cargs = Namespace(
-            current_version='0.0.1',
+            current_version="0.0.1",
             next_version=release_version,
             output=output,
-            space='foo',
-            project='bar',
+            space="foo",
+            project="bar",
             config=config_toml,
         )
         changelog_builder = changelog.ChangelogBuilder(
-            shell_cmd_runner=runner,
+            terminal=terminal,
             args=cargs,
         )
 
@@ -158,53 +150,50 @@ All notable changes to this project will be documented in this file.
             output_file = changelog_builder.create_changelog_file()
 
             self.assertIsNone(output_file)
-            self.assertIn(
+            shell_mock.assert_called_with(
                 'git log "$(git describe --tags --abbrev=0)..HEAD" --oneline',
-                called,
             )
 
-    def test_changelog_builder_no_tag(self):
+    @patch("pontos.changelog.conventional_commits.shell_cmd_runner")
+    def test_changelog_builder_no_tag(self, shell_mock):
+        terminal = MagicMock()
 
-        _set_terminal(Terminal())
-
-        today = datetime.today().strftime('%Y-%m-%d')
+        today = datetime.today().strftime("%Y-%m-%d")
 
         own_path = Path(__file__).absolute().parent
-        print(own_path)
-        config_toml = own_path / 'changelog.toml'
-        release_version = '0.0.2'
-        output = f'v{release_version}.md'
-        git_tag = ""
-        git_log = (
-            '1234567 Add: foo bar\n'
-            '8abcdef Add: bar baz\n'
-            '8abcd3f Add bar baz\n'
-            '8abcd3d Adding bar baz\n'
-            '1337abc Change: bar to baz\n'
-            '42a42a4 Remove: foo bar again\n'
-            'fedcba8 Test: bar baz testing\n'
-            'dead901 Refactor: bar baz ref\n'
-            'fedcba8 Fix: bar baz fixing\n'
-            'd0c4d0c Doc: bar baz documenting\n'
-        )
-        called = []
-
-        def runner(cmd):
-            called.append(cmd)
-            if cmd == "git tag | sort -V | tail -1":
-                return StdOutput(git_tag)
-            return StdOutput(git_log)
+        config_toml = own_path / "changelog.toml"
+        release_version = "0.0.2"
+        output = f"v{release_version}.md"
+        shell_mock.side_effect = [
+            CompletedProcess(args=None, returncode=1, stdout=""),
+            CompletedProcess(
+                args=None,
+                returncode=1,
+                stdout=(
+                    "1234567 Add: foo bar\n"
+                    "8abcdef Add: bar baz\n"
+                    "8abcd3f Add bar baz\n"
+                    "8abcd3d Adding bar baz\n"
+                    "1337abc Change: bar to baz\n"
+                    "42a42a4 Remove: foo bar again\n"
+                    "fedcba8 Test: bar baz testing\n"
+                    "dead901 Refactor: bar baz ref\n"
+                    "fedcba8 Fix: bar baz fixing\n"
+                    "d0c4d0c Doc: bar baz documenting\n"
+                ),
+            ),
+        ]
 
         cargs = Namespace(
-            current_version='0.0.1',
+            current_version="0.0.1",
             next_version=release_version,
             output=output,
-            space='foo',
-            project='bar',
+            space="foo",
+            project="bar",
             config=config_toml,
         )
         changelog_builder = changelog.ChangelogBuilder(
-            shell_cmd_runner=runner,
+            terminal=terminal,
             args=cargs,
         )
         expected_output = f"""# Changelog
@@ -237,43 +226,40 @@ All notable changes to this project will be documented in this file.
 
 [0.0.2]: https://github.com/foo/bar/compare/0.0.1...0.0.2"""
         output_file = changelog_builder.create_changelog_file()
-        print(output_file.read_text(encoding='utf-8'))
         self.assertEqual(
-            output_file.read_text(encoding='utf-8'), expected_output
+            output_file.read_text(encoding="utf-8"), expected_output
         )
 
-        self.assertIn(
-            'git log HEAD --oneline',
-            called,
+        shell_mock.assert_has_calls(
+            [
+                call("git tag | sort -V | tail -1"),
+                call("git log HEAD --oneline"),
+            ]
         )
 
         output_file.unlink()
 
-    def test_changelog_builder_no_conventional_commits(self):
-
-        _set_terminal(Terminal())
+    @patch("pontos.changelog.conventional_commits.shell_cmd_runner")
+    def test_changelog_builder_no_conventional_commits(self, shell_mock):
+        terminal = MagicMock()
 
         own_path = Path(__file__).absolute().parent
-        config_toml = own_path / 'changelog.toml'
-        release_version = '0.0.2'
-        output = f'v{release_version}.md'
-        git_log = None
-        called = []
-
-        def runner(cmd):
-            called.append(cmd)
-            return StdOutput(git_log)
-
+        config_toml = own_path / "changelog.toml"
+        release_version = "0.0.2"
+        output = f"v{release_version}.md"
+        shell_mock.return_value = CompletedProcess(
+            args="foo", returncode=1, stdout=None
+        )
         cargs = Namespace(
-            current_version='0.0.1',
+            current_version="0.0.1",
             next_version=release_version,
             output=output,
-            space='foo',
-            project='bar',
+            space="foo",
+            project="bar",
             config=config_toml,
         )
         changelog_builder = changelog.ChangelogBuilder(
-            shell_cmd_runner=runner,
+            terminal=terminal,
             args=cargs,
         )
 
@@ -281,7 +267,15 @@ All notable changes to this project will be documented in this file.
             output_file = changelog_builder.create_changelog_file()
 
             self.assertIsNone(output_file)
-            self.assertIn(
+            shell_mock.assert_called_with(
                 'git log "$(git describe --tags --abbrev=0)..HEAD" --oneline',
-                called,
             )
+
+    def test_parse_args(self):
+        parsed_args = parse_args(
+            ["-q", "--log-file", "blah", "--project", "urghs"]
+        )
+
+        self.assertTrue(parsed_args.quiet)
+        self.assertEqual(parsed_args.log_file, "blah")
+        self.assertEqual(parsed_args.project, "urghs")
