@@ -17,14 +17,13 @@
 
 import json
 import unittest
-
 from pathlib import Path
-from unittest.mock import patch, MagicMock
+from unittest.mock import MagicMock, patch
 
 from pontos.github.api import (
+    DEFAULT_TIMEOUT,
     FileStatus,
     GitHubRESTApi,
-    DEFAULT_TIMEOUT,
     download,
 )
 
@@ -42,10 +41,10 @@ class GitHubApiTestCase(unittest.TestCase):
         exists = api.branch_exists("foo/bar", "main")
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/branches/main',
+            "https://api.github.com/repos/foo/bar/branches/main",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json=None,
@@ -62,10 +61,10 @@ class GitHubApiTestCase(unittest.TestCase):
         exists = api.branch_exists("foo/bar", "main")
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/branches/main',
+            "https://api.github.com/repos/foo/bar/branches/main",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json=None,
@@ -75,18 +74,19 @@ class GitHubApiTestCase(unittest.TestCase):
     @patch("pontos.github.api.requests.get")
     def test_pull_request_commits(self, requests_mock: MagicMock):
         response = MagicMock()
+        response.links = None
         response.json.return_value = [{"sha": "1"}]
         requests_mock.return_value = response
         api = GitHubRESTApi("12345")
         commits = api.pull_request_commits("foo/bar", pull_request=1)
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/pulls/1/commits',
+            "https://api.github.com/repos/foo/bar/pulls/1/commits",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
-            params={'per_page': '100'},
+            params={"per_page": "100"},
             json=None,
         )
 
@@ -105,17 +105,42 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/pulls',
+            "https://api.github.com/repos/foo/bar/pulls",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json={
-                'head': 'foo',
-                'base': 'main',
-                'title': 'Foo',
-                'body': 'This is bar',
+                "head": "foo",
+                "base": "main",
+                "title": "Foo",
+                "body": "This is bar",
+            },
+        )
+
+    @patch("pontos.github.api.requests.post")
+    def test_update_pull_request(self, requests_mock: MagicMock):
+        api = GitHubRESTApi("12345")
+        api.update_pull_request(
+            "foo/bar",
+            123,
+            base_branch="main",
+            title="Foo",
+            body="This is bar",
+        )
+
+        requests_mock.assert_called_once_with(
+            "https://api.github.com/repos/foo/bar/pulls/123",
+            headers={
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
+            },
+            params=None,
+            json={
+                "base": "main",
+                "title": "Foo",
+                "body": "This is bar",
             },
         )
 
@@ -127,13 +152,13 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/issues/123/comments',
+            "https://api.github.com/repos/foo/bar/issues/123/comments",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
-            json={'body': 'This is a comment'},
+            json={"body": "This is a comment"},
         )
 
     @patch("pontos.github.api.requests.delete")
@@ -142,10 +167,10 @@ class GitHubApiTestCase(unittest.TestCase):
         api.delete_branch("foo/bar", "foo")
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/git/refs/foo',
+            "https://api.github.com/repos/foo/bar/git/refs/foo",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json=None,
@@ -162,19 +187,19 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/releases',
+            "https://api.github.com/repos/foo/bar/releases",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json={
-                'tag_name': 'v1.2.3',
-                'target_commitish': None,
-                'name': 'Foo v1.2.3',
-                'body': 'This is a release',
-                'draft': False,
-                'prerelease': False,
+                "tag_name": "v1.2.3",
+                "target_commitish": None,
+                "name": "Foo v1.2.3",
+                "body": "This is a release",
+                "draft": False,
+                "prerelease": False,
             },
         )
 
@@ -188,10 +213,10 @@ class GitHubApiTestCase(unittest.TestCase):
         exists = api.release_exists("foo/bar", "v1.2.3")
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/releases/tags/v1.2.3',
+            "https://api.github.com/repos/foo/bar/releases/tags/v1.2.3",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json=None,
@@ -211,10 +236,10 @@ class GitHubApiTestCase(unittest.TestCase):
         data = api.release("greenbone/pontos", "v21.11.0")
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/greenbone/pontos/releases/tags/v21.11.0',  # pylint: disable=line-too-long
+            "https://api.github.com/repos/greenbone/pontos/releases/tags/v21.11.0",  # pylint: disable=line-too-long
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
             params=None,
             json=None,
@@ -241,11 +266,11 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz',  # pylint: disable=line-too-long
+            "https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz",  # pylint: disable=line-too-long
             stream=True,
             timeout=DEFAULT_TIMEOUT,
         )
-        response_headers.get.assert_called_once_with('content-length')
+        response_headers.get.assert_called_once_with("content-length")
 
         self.assertIsNone(download_progress.length)
 
@@ -279,11 +304,11 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz',  # pylint: disable=line-too-long
+            "https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz",  # pylint: disable=line-too-long
             stream=True,
             timeout=DEFAULT_TIMEOUT,
         )
-        response_headers.get.assert_called_once_with('content-length')
+        response_headers.get.assert_called_once_with("content-length")
 
         self.assertEqual(download_progress.length, 9)
 
@@ -317,11 +342,11 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.zip',  # pylint: disable=line-too-long
+            "https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.zip",  # pylint: disable=line-too-long
             stream=True,
             timeout=DEFAULT_TIMEOUT,
         )
-        response_headers.get.assert_called_once_with('content-length')
+        response_headers.get.assert_called_once_with("content-length")
 
         self.assertIsNone(download_progress.length)
 
@@ -339,6 +364,7 @@ class GitHubApiTestCase(unittest.TestCase):
     @patch("pontos.github.api.requests.get")
     def test_modified_files_in_pr(self, requests_mock: MagicMock):
         response = MagicMock()
+        response.links = None
         response.json.return_value = json.loads(
             (here / "pr-files.json").read_text(encoding="utf-8")
         )
@@ -349,12 +375,12 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/pulls/1/files',
+            "https://api.github.com/repos/foo/bar/pulls/1/files",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
-            params={'per_page': '100'},
+            params={"per_page": "100"},
             json=None,
         )
 
@@ -376,6 +402,7 @@ class GitHubApiTestCase(unittest.TestCase):
     @patch("pontos.github.api.requests.get")
     def test_added_files_in_pr(self, requests_mock: MagicMock):
         response = MagicMock()
+        response.links = None
         response.json.return_value = json.loads(
             (here / "pr-files.json").read_text(encoding="utf-8")
         )
@@ -386,12 +413,12 @@ class GitHubApiTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://api.github.com/repos/foo/bar/pulls/1/files',
+            "https://api.github.com/repos/foo/bar/pulls/1/files",
             headers={
-                'Authorization': 'token 12345',
-                'Accept': 'application/vnd.github.v3+json',
+                "Authorization": "token 12345",
+                "Accept": "application/vnd.github.v3+json",
             },
-            params={'per_page': '100'},
+            params={"per_page": "100"},
             json=None,
         )
 
@@ -427,11 +454,11 @@ class DownloadTestCase(unittest.TestCase):
         )
 
         requests_mock.assert_called_once_with(
-            'https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz',  # pylint: disable=line-too-long
+            "https://github.com/greenbone/pontos/archive/refs/tags/v21.11.0.tar.gz",  # pylint: disable=line-too-long
             stream=True,
             timeout=DEFAULT_TIMEOUT,
         )
-        response_headers.get.assert_called_once_with('content-length')
+        response_headers.get.assert_called_once_with("content-length")
 
         self.assertIsNone(download_progress.length)
         self.assertEqual(download_progress.destination, Path("v21.11.0.tar.gz"))
@@ -476,7 +503,7 @@ class DownloadTestCase(unittest.TestCase):
             stream=True,
             timeout=DEFAULT_TIMEOUT,
         )
-        response_headers.get.assert_called_once_with('content-length')
+        response_headers.get.assert_called_once_with("content-length")
 
         self.assertEqual(download_progress.length, 9)
 
