@@ -19,13 +19,13 @@
 # pylint: disable=protected-access
 
 
-import unittest
 import contextlib
 import io
-
+import unittest
 from pathlib import Path
 from unittest.mock import MagicMock, patch
-from pontos.version.cmake import CMakeVersionParser, CMakeVersionCommand
+
+from pontos.version.cmake import CMakeVersionCommand, CMakeVersionParser
 from pontos.version.helper import VersionError
 
 
@@ -33,7 +33,7 @@ class CMakeVersionCommandTestCase(unittest.TestCase):
     def test_raise_exception_file_not_exists(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = False
         with self.assertRaises(VersionError):
             CMakeVersionCommand(project_file_path=fake_path)
@@ -41,12 +41,12 @@ class CMakeVersionCommandTestCase(unittest.TestCase):
     def test_raise_exception_no_project(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = ""
         with self.assertRaises(ValueError):
-            CMakeVersionCommand(project_file_path=fake_path).run(args=['show'])
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+            CMakeVersionCommand(project_file_path=fake_path).run(args=["show"])
+        fake_path.read_text.assert_called_with(encoding="utf-8")
 
     def test_raise_exception_file_not_found(self):
         with self.assertRaises(
@@ -57,7 +57,7 @@ class CMakeVersionCommandTestCase(unittest.TestCase):
     def test_return_error_string_incorrect_version_on_verify(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = (
             "project(VERSION so_much_version_so_much_wow)\n"
@@ -65,100 +65,101 @@ class CMakeVersionCommandTestCase(unittest.TestCase):
         )
 
         result = CMakeVersionCommand(project_file_path=fake_path).run(
-            args=['verify', 'so_much_version_so_much_wow']
+            args=["verify", "so_much_version_so_much_wow"]
         )
         self.assertTrue(
             isinstance(result, str), "expected result to be an error string"
         )
         self.assertEqual(
             result,
-            'The version so_much_version_so_much_wow is not PEP 440 compliant.',
+            "The version so_much_version_so_much_wow is not PEP 440 compliant.",
         )
 
     @patch(
-        'pontos.version.cmake.CMakeVersionCommand.get_current_version',
-        MagicMock(return_value='21.4'),
+        "pontos.version.cmake.CMakeVersionCommand.get_current_version",
+        MagicMock(return_value="21.4"),
     )
-    @patch('pontos.version.cmake.CMakeVersionCommand._print')
+    @patch("pontos.version.cmake.CMakeVersionCommand._print")
     def test_return_0_correct_version_on_verify(self, print_mock):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = ""
 
         result = CMakeVersionCommand(project_file_path=fake_path).run(
-            args=['verify', '21.4']
+            args=["verify", "21.4"]
         )
         self.assertEqual(0, result)
-        print_mock.assert_called_with('OK')
+        print_mock.assert_called_with("OK")
 
     def test_should_call_print_current_version_without_raising_exception(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = "project(VERSION 21)"
-        CMakeVersionCommand(project_file_path=fake_path).run(args=['show'])
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+        CMakeVersionCommand(project_file_path=fake_path).run(args=["show"])
+        fake_path.read_text.assert_called_with(encoding="utf-8")
 
     def test_raise_update_version(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = (
             "project(VERSION 21)\nset(PROJECT_DEV_VERSION 0)"
         )
-        CMakeVersionCommand(project_file_path=fake_path).run(
-            args=['update', '22', '--develop']
-        )
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+        with contextlib.redirect_stdout(io.StringIO()):
+            CMakeVersionCommand(project_file_path=fake_path).run(
+                args=["update", "22", "--develop"]
+            )
+        fake_path.read_text.assert_called_with(encoding="utf-8")
         fake_path.write_text.assert_called_with(
-            'project(VERSION 22)\nset(PROJECT_DEV_VERSION 1)', encoding='utf-8'
+            "project(VERSION 22)\nset(PROJECT_DEV_VERSION 1)", encoding="utf-8"
         )
 
     def test_update_version_equal_not_force(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'CMakeLists.txt'
+        fake_path.__str__.return_value = "CMakeLists.txt"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = (
             "project(VERSION 22)\nset(PROJECT_DEV_VERSION 0)"
         )
-        with io.StringIO() as buf, contextlib.redirect_stdout(buf):
+        with contextlib.redirect_stdout(io.StringIO()) as buf:
             CMakeVersionCommand(project_file_path=fake_path).run(
-                args=['update', '22', '--develop']
+                args=["update", "22", "--develop"]
             )
-            self.assertEqual(buf.getvalue(), 'Version is already up-to-date.\n')
-            fake_path.read_text.assert_called_with(encoding='utf-8')
+            self.assertEqual(buf.getvalue(), "Version is already up-to-date.\n")
+            fake_path.read_text.assert_called_with(encoding="utf-8")
 
 
 class CMakeVersionParserTestCase(unittest.TestCase):
     def test_get_current_version_single_line_project(self):
         under_test = CMakeVersionParser("project(VERSION 2.3.4)")
-        self.assertEqual(under_test.get_current_version(), '2.3.4')
+        self.assertEqual(under_test.get_current_version(), "2.3.4")
 
     def test_update_version_project(self):
         under_test = CMakeVersionParser("project(VERSION 2.3.4)")
         self.assertEqual(
-            under_test.update_version('2.3.5'), "project(VERSION 2.3.5)"
+            under_test.update_version("2.3.5"), "project(VERSION 2.3.5)"
         )
 
     def test_update_raise_exception_when_version_is_incorrect(self):
         under_test = CMakeVersionParser("project(VERSION 2.3.4)")
         with self.assertRaises(VersionError):
-            under_test.update_version('so_much_version_so_much_wow')
+            under_test.update_version("so_much_version_so_much_wow")
 
     def test_not_confuse_version_outside_project(self):
         under_test = CMakeVersionParser(
             "non_project(VERSION 2.3.5)\nproject(VERSION 2.3.4)"
         )
-        self.assertEqual(under_test.get_current_version(), '2.3.4')
+        self.assertEqual(under_test.get_current_version(), "2.3.4")
 
     def test_get_current_version_multiline_project(self):
         under_test = CMakeVersionParser("project\n(\nVERSION\n\t    2.3.4)")
-        self.assertEqual(under_test.get_current_version(), '2.3.4')
+        self.assertEqual(under_test.get_current_version(), "2.3.4")
 
     def test_find_project_dev_version(self):
         test_cmake_lists = """
@@ -173,7 +174,7 @@ class CMakeVersionParserTestCase(unittest.TestCase):
         """
         under_test = CMakeVersionParser(test_cmake_lists)
         self.assertEqual(under_test._project_dev_version_line_number, 7)
-        self.assertEqual(under_test._project_dev_version, '1')
+        self.assertEqual(under_test._project_dev_version, "1")
 
     def test_update_project_dev_version(self):
         test_cmake_lists = """
@@ -189,13 +190,13 @@ class CMakeVersionParserTestCase(unittest.TestCase):
         under_test = CMakeVersionParser(test_cmake_lists)
 
         self.assertEqual(under_test._project_dev_version_line_number, 7)
-        self.assertEqual(under_test._project_dev_version, '1')
-        result = under_test.update_version('41.41.41', develop=False)
-        self.assertEqual(under_test._project_dev_version, '0')
+        self.assertEqual(under_test._project_dev_version, "1")
+        result = under_test.update_version("41.41.41", develop=False)
+        self.assertEqual(under_test._project_dev_version, "0")
         self.assertEqual(
             result,
             test_cmake_lists.replace(
-                'PROJECT_DEV_VERSION 1', 'PROJECT_DEV_VERSION 0'
+                "PROJECT_DEV_VERSION 1", "PROJECT_DEV_VERSION 0"
             ),
         )
 
@@ -211,13 +212,13 @@ class CMakeVersionParserTestCase(unittest.TestCase):
         under_test = CMakeVersionParser(test_cmake_lists)
 
         self.assertEqual(under_test._project_dev_version_line_number, 4)
-        self.assertEqual(under_test._project_dev_version, '1')
-        result = under_test.update_version('41.41.41', develop=False)
-        self.assertEqual(under_test._project_dev_version, '0')
+        self.assertEqual(under_test._project_dev_version, "1")
+        result = under_test.update_version("41.41.41", develop=False)
+        self.assertEqual(under_test._project_dev_version, "0")
         self.assertEqual(
             result,
             test_cmake_lists.replace(
-                'PROJECT_DEV_VERSION 1', 'PROJECT_DEV_VERSION 0'
+                "PROJECT_DEV_VERSION 1", "PROJECT_DEV_VERSION 0"
             ),
         )
 
@@ -225,13 +226,13 @@ class CMakeVersionParserTestCase(unittest.TestCase):
         under_test = CMakeVersionParser(
             "project\n(\nDESCRIPTION something VERSION 2.3.4 LANGUAGES c\n)"
         )
-        self.assertEqual(under_test.get_current_version(), '2.3.4')
+        self.assertEqual(under_test.get_current_version(), "2.3.4")
 
     def test_raise_exception_project_no_version(self):
         with self.assertRaises(ValueError) as context:
             CMakeVersionParser("project(DESCRIPTION something LANGUAGES c)")
         self.assertEqual(
-            str(context.exception), 'unable to find cmake version in project.'
+            str(context.exception), "unable to find cmake version in project."
         )
 
     def test_raise_exception_no_project(self):
@@ -241,5 +242,5 @@ class CMakeVersionParserTestCase(unittest.TestCase):
             )
 
         self.assertEqual(
-            str(context.exception), 'unable to find cmake version.'
+            str(context.exception), "unable to find cmake version."
         )
