@@ -17,23 +17,22 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
-
 from pathlib import Path
 from unittest.mock import MagicMock
 
-from pontos.version.python import PythonVersionCommand
 from pontos.version.helper import VersionError
+from pontos.version.python import PythonVersionCommand
 
 
 class GetVersionFromPyprojectTomlTestCase(unittest.TestCase):
     def test_pyproject_toml_file_not_exists(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'pyproject.toml'
+        fake_path.__str__.return_value = "pyproject.toml"
         fake_path.exists.return_value = False
 
         with self.assertRaisesRegex(
-            VersionError, 'pyproject.toml file not found'
+            VersionError, "pyproject.toml file not found"
         ):
             PythonVersionCommand(project_file_path=fake_path)
 
@@ -42,25 +41,25 @@ class GetVersionFromPyprojectTomlTestCase(unittest.TestCase):
     def test_no_poerty_section(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'pyproject.toml'
+        fake_path.__str__.return_value = "pyproject.toml"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = (
             '[tool.pontos.version]\nversion-module-file = "foo.py"'
         )
 
         with self.assertRaisesRegex(
-            VersionError, 'Version information not found in pyproject.toml file'
+            VersionError, "Version information not found in pyproject.toml file"
         ):
             cmd = PythonVersionCommand(project_file_path=fake_path)
             cmd._get_version_from_pyproject_toml()  # pylint: disable=protected-access
 
         fake_path.exists.assert_called_with()
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+        fake_path.read_text.assert_called_with(encoding="utf-8")
 
     def test_empty_poetry_section(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'pyproject.toml'
+        fake_path.__str__.return_value = "pyproject.toml"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = """
         [tool.poetry]
@@ -68,18 +67,18 @@ class GetVersionFromPyprojectTomlTestCase(unittest.TestCase):
         """
 
         with self.assertRaisesRegex(
-            VersionError, 'Version information not found in pyproject.toml file'
+            VersionError, "Version information not found in pyproject.toml file"
         ):
             cmd = PythonVersionCommand(project_file_path=fake_path)
             cmd._get_version_from_pyproject_toml()  # pylint: disable=protected-access
 
         fake_path.exists.assert_called_with()
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+        fake_path.read_text.assert_called_with(encoding="utf-8")
 
     def test_get_version(self):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
-        fake_path.__str__.return_value = 'pyproject.toml'
+        fake_path.__str__.return_value = "pyproject.toml"
         fake_path.exists.return_value = True
         fake_path.read_text.return_value = """
         [tool.poetry]\nversion = "1.2.3"
@@ -90,7 +89,7 @@ class GetVersionFromPyprojectTomlTestCase(unittest.TestCase):
         # pylint: disable=protected-access
         version = cmd._get_version_from_pyproject_toml()
 
-        self.assertEqual(version, '1.2.3')
+        self.assertEqual(version, "1.2.3")
 
         fake_path.exists.assert_called_with()
-        fake_path.read_text.assert_called_with(encoding='utf-8')
+        fake_path.read_text.assert_called_with(encoding="utf-8")
