@@ -16,7 +16,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
-
 from unittest.mock import MagicMock
 
 from pontos.version.version import VersionCommand
@@ -25,10 +24,10 @@ from pontos.version.version import VersionCommand
 class PrintCurrentVersionTestCase(unittest.TestCase):
     def test_print_current_version(self):
         print_mock = MagicMock()
-        VersionCommand.get_current_version = MagicMock(return_value='1.2.3')
+        VersionCommand.get_current_version = MagicMock(return_value="1.2.3")
         VersionCommand._print = print_mock  # pylint: disable=protected-access
 
         cmd = VersionCommand()
         cmd.print_current_version()
 
-        print_mock.assert_called_with('1.2.3')
+        print_mock.assert_called_with("1.2.3")
